/*
** ---------------------------------------------------------------------------
** SVN Repository ...: $HeadURL: file:///Data/_Privat/Programmieren/Source-Repository/SVN/BeanDocument/trunk/src/net/beandocument/BeanCollectionElement.java $
** Author ...........: $LastChangedBy: jscheffl $
** Modified .........: $LastChangedDate: 2005-02-27 15:11:14 +0100 (So, 27 Feb 2005) $
** Revision .........: $LastChangedRevision: 11 $
** Responsible ......: Jens Scheffler
** Initial version ..: Jens Scheffler
** ---------------------------------------------------------------------------
*/
package net.beandocument;

import junit.framework.TestCase;

/**
 * Test Case for BeanNamedNodeMap class.
 * @author Jens Scheffler
 */
public class BeanNamedNodeMapTest extends TestCase {

    private BeanNamedNodeMap nnm;
    
    /**
     * @see TestCase#setUp()
     */
    protected void setUp() throws Exception {
        super.setUp();
        
        BeanDocument doc = new BeanDocument(new BeanElementFactory(), this);
        BeanElement owner = new BeanSimpleTypeElement(doc, doc, "test", this);
        BeanAttribute attr1 = new BeanAttribute(doc, owner, "name1", "value1");
        BeanAttribute attr2 = new BeanAttribute(doc, owner, "name2", "value2");
        BeanAttribute attr3 = new BeanAttribute(doc, owner, "name3", "value3");
        nnm = new BeanNamedNodeMap();
        nnm.add("name1", attr1);
        nnm.add("name2", attr2);
        nnm.add("name3", attr3);
    }

    /**
     * A Test Case
     */
    public final void testAdd() {
        BeanDocument doc = new BeanDocument(new BeanElementFactory(), this);
        BeanElement owner = new BeanSimpleTypeElement(doc, doc, "test", this);
        BeanAttribute attr = new BeanAttribute(doc, owner, "name", "value");
        assertEquals(3, nnm.getLength());
        nnm.add("name", attr);
        assertEquals(4, nnm.getLength());
    }

    /**
     * A Test Case
     */
    public final void testGetLength() {
        assertEquals(3, nnm.getLength());
    }

    /**
     * A Test Case
     */
    public final void testGetNamedItem() {
        assertTrue(nnm.getNamedItem("name1") instanceof BeanAttribute);
        assertNull(nnm.getNamedItem("xxx"));
    }

    /**
     * A Test Case
     */
    public final void testGetNamedItemNS() {
        assertTrue(nnm.getNamedItemNS(null, "name1") instanceof BeanAttribute);
        assertNull(nnm.getNamedItemNS("ns", "name1"));
        assertNull(nnm.getNamedItemNS("ns", "xxx"));
    }

    /**
     * A Test Case
     */
    public final void testItem() {
        assertTrue(nnm.item(0) instanceof BeanAttribute);
        assertTrue(nnm.item(1) instanceof BeanAttribute);
        assertTrue(nnm.item(2) instanceof BeanAttribute);
        try {
            nnm.item(3);
        } catch (ArrayIndexOutOfBoundsException e) {
            return;
        }
        assertTrue(false);
    }

    /**
     * A Test Case
     */
    public final void testRemoveNamedItem() {
        assertEquals(3, nnm.getLength());
        assertNull(nnm.removeNamedItem("xxx"));
        assertEquals(3, nnm.getLength());
        assertTrue(nnm.removeNamedItem("name1") instanceof BeanAttribute);
        assertEquals(2, nnm.getLength());
        assertNull(nnm.removeNamedItem("name1"));
        assertEquals(2, nnm.getLength());
    }

    /**
     * A Test Case
     */
    public final void testRemoveNamedItemNS() {
        assertEquals(3, nnm.getLength());
        assertNull(nnm.removeNamedItemNS("ns", "xxx"));
        assertEquals(3, nnm.getLength());
        assertNull(nnm.removeNamedItemNS("ns", "name1"));
        assertEquals(3, nnm.getLength());
        assertTrue(nnm.removeNamedItemNS(null, "name1") instanceof BeanAttribute);
        assertEquals(2, nnm.getLength());
    }

    /**
     * A Test Case
     */
    public final void testSetNamedItem() {
        BeanDocument doc = new BeanDocument(new BeanElementFactory(), this);
        BeanElement owner = new BeanSimpleTypeElement(doc, doc, "test", this);
        BeanAttribute attr = new BeanAttribute(doc, owner, "name", "value");
        assertEquals(3, nnm.getLength());
        assertNull(nnm.setNamedItem(attr));
        assertEquals(4, nnm.getLength());
        assertTrue(nnm.setNamedItem(attr) instanceof BeanAttribute);
        assertEquals(4, nnm.getLength());
    }

    /**
     * A Test Case
     */
    public final void testSetNamedItemNS() {
        BeanDocument doc = new BeanDocument(new BeanElementFactory(), this);
        BeanElement owner = new BeanSimpleTypeElement(doc, doc, "test", this);
        BeanAttribute attr = new BeanAttribute(doc, owner, "name", "value");
        assertEquals(3, nnm.getLength());
        assertNull(nnm.setNamedItemNS(attr));
        assertEquals(4, nnm.getLength());
        assertTrue(nnm.setNamedItemNS(attr) instanceof BeanAttribute);
        assertEquals(4, nnm.getLength());
    }
}
